<?php
/*
Plugin Name: Google Analytics Link (GAL)
Plugin URI: http://www.mandsconsulting.com/
Description: Google Analytics Link (GAL) gives WordPress Administrators super-quick access to the current page's or post's Google Analytics information
Author: M&S Consulting
Version: 1.6
Author URI: http://www.mandsconsulting.com

============================================================================================================
This software is provided "as is" and any express or implied warranties, including, but not limited to, the
implied warranties of merchantibility and fitness for a particular purpose are disclaimed. In no event shall
the copyright owner or contributors be liable for any direct, indirect, incidental, special, exemplary, or
consequential damages(including, but not limited to, procurement of substitute goods or services; loss of
use, data, or profits; or business interruption) however caused and on any theory of liability, whether in
contract, strict liability, or tort(including negligence or otherwise) arising in any way out of the use of
this software, even if advised of the possibility of such damage.

For full license details see license.txt
============================================================================================================
*/

add_filter( 'plugin_action_links', 'gal_plugin_action_links', 10, 2 );

function gal_plugin_action_links( $links, $file ) {
	if ( $file != plugin_basename( __FILE__ ))
		return $links;

	$settings_link = '<a href="options-general.php?page=google-analytics-link">' . __( 'Settings', 'google-analytics-link' ) . '</a>';

	array_unshift( $links, $settings_link );

	return $links;
}

add_action('admin_menu', 'gal_plugin_menu');


function google_analytics_admin_bar() {
    global $wp_admin_bar;

    if(current_user_can('manage_options')){

       $siteurl =  get_option( 'siteurl' );
       $url_parts = explode($siteurl, get_permalink( ));
       $page_url = $url_parts[1];
       $gpalUrl = '';

     if(get_option('google_analytics_link_id') != null){

       $gpalUrl =  'https://www.google.com/analytics/web/#report/content-pages/'. get_option('google_analytics_li           nk_id') . '/%3F_r.drilldown%3Danalytics.pagePath%3A'. urlencode($page_url);

     }
     else{
	$gpalUrl = admin_url() . 'options-general.php?page=google-analytics-link';
     }
   }

    $wp_admin_bar->add_menu( array(
        'id' => 'google_analytics_link',
        'title' => __('Google Analytics Link (GAL)'),
        'href' => $gpalUrl,
        'meta' => array('target' =>'_blank')
    ) );
}
add_action( 'wp_before_admin_bar_render', 'google_analytics_admin_bar' );



function gal_plugin_menu() {

  add_options_page('Google Analytics Link (GAL)', 'Google Analytics Link (GAL)', 'manage_options', 'google-analytics-link', 'google_analytics_link_options');
  add_action( 'admin_init', 'register_google_analytics_link_settings' );

}

function register_google_analytics_link_settings() {
  register_setting( 'google-analytcs-link-group', 'google_analytics_link_id' );

}


function google_analytics_link_options() {

  if (!current_user_can('manage_options'))  {
    wp_die( __('You do not have sufficient permissions to access this page.') );
  }

?>
<style type="text/css">
.ebd th, .ebd td
{
vertical-align:top;
}
.ebd th
{
	text-align: left;
	padding-right:8px;
}
.ebd .alert
{
	padding:8px;
	font:bold 12pt Arial;
	border:1px dashed red;
}
</style>

<div class="wrap">
<h2>Google Analytics Link (GAL) Configuration</h2>

<p> Google Analytics Link (GAL) provides a link placed on the Admin Bar (aka ToolBar) to your Google Analytics account.</p>
<p> <h3>Instructions:</h3>You can set the Google ID from the plugin's settings page. To get your Google Analytics URL ID, navigate to <a target="_blank" href="https://www.google.com/analytics">Google Analytics</a> and review the URL in your browser. You should see something like: https://www.google.com/analytics/web/?et&authuser=0#report/visitors-overview/axxxxxxxxxxxxxxxxxxxxxx3428/ and your Google Analytics URL ID is the part that looks like the following: axxxxxxxxxxxxxxxxxxxxxx3428. You should place this into the GAL plugin settings page.

<iframe width="560" height="315" src="//www.youtube.com/embed/6YGXjI1KHzk" frameborder="0" allowfullscreen></iframe>

<p> Thank you for your support!</p>

<form action="https://www.paypal.com/cgi-bin/webscr" method="post" target="_blank">
<input type="hidden" name="cmd" value="_s-xclick" />
<input type="hidden" name="hosted_button_id" value="47FLSBA363KAU" />
<input type="image" name="submit" src="https://www.paypalobjects.com/en_US/i/btn/btn_donate_SM.gif" alt="PayPal - The safer, easier way to pay online!" />
<img src="https://www.paypalobjects.com/en_US/i/scr/pixel.gif" alt="" width="1" height="1" border="0" />
</form>

<form method="post" action="options.php">
    <?php settings_fields( 'google-analytcs-link-group' ); ?>
    <table class="optiontable ebd">

        <tr valign="top">
        <th scope="row"><p>Google Analytics URL ID</p></th>
        <td><p><input type="text" size="40" name="google_analytics_link_id" value="<?php echo get_option('google_analytics_link_id'); ?>" />
        <br /> <font size="-1"><i></i></font>
        </td>
        </tr>
    </table>

    <p class="submit">
    <input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
    </p>

</form>
</div>
<?php

}

?>